SuperLU: SRC/ilu_relax_snode.c File Reference

SuperLU 7.0.1

Functions
ilu_relax_snode.c File Reference
Common

Identify initial relaxed supernodes. More...

`#include "slu_ddefs.h"`
Include dependency graph for ilu_relax_snode.c:

## Functions
void | ilu_relax_snode (const int n, const int *et, const int relax_columns, int *descendants, int *relax_end, int *relax_fsupc)

## Function Documentation

## ◆ ilu_relax_snode()

void ilu_relax_snode | ( | const int | n,
|  | const int * | et,
|  | const int | relax_columns,
|  | int * | descendants,
|  | int * | relax_end,
|  | int * | relax_fsupc
| ) |  |

    Purpose
    =======
       ilu_relax_snode() - Identify the initial relaxed supernodes, assuming
       that the matrix has been reordered according to the postorder of the
       etree.

Here is the call graph for this function: